@@ -39,13 +39,13 @@ _eXosip_insubscription_transaction_find (int tid, eXosip_notify_t ** jn,
         {
           *tr = (*jn)->n_inc_tr;
           *jd = (*jn)->n_dialogs;
-          return 0;
+          return OSIP_SUCCESS;
         }
       if ((*jn)->n_out_tr != NULL && (*jn)->n_out_tr->transactionid == tid)
         {
           *tr = (*jn)->n_out_tr;
           *jd = (*jn)->n_dialogs;
-          return 0;
+          return OSIP_SUCCESS;
         }
       for (*jd = (*jn)->n_dialogs; *jd != NULL; *jd = (*jd)->next)
         {
@@ -59,7 +59,7 @@ _eXosip_insubscription_transaction_find (int tid, eXosip_notify_t ** jn,
               if (transaction != NULL && transaction->transactionid == tid)
                 {
                   *tr = transaction;
-                  return 0;
+                  return OSIP_SUCCESS;
                 }
               pos++;
             }
@@ -72,7 +72,7 @@ _eXosip_insubscription_transaction_find (int tid, eXosip_notify_t ** jn,
               if (transaction != NULL && transaction->transactionid == tid)
                 {
                   *tr = transaction;
-                  return 0;
+                  return OSIP_SUCCESS;
                 }
               pos++;
             }
@@ -80,14 +80,18 @@ _eXosip_insubscription_transaction_find (int tid, eXosip_notify_t ** jn,
     }
   *jd = NULL;
   *jn = NULL;
-  return -1;
+  return OSIP_NOTFOUND;
 }
 
-int eXosip_insubscription_remove (int did)
+int
+eXosip_insubscription_remove (int did)
 {
   eXosip_dialog_t *jd = NULL;
   eXosip_notify_t *jn = NULL;
 
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
+
   if (did > 0)
     {
       eXosip_notify_dialog_find (did, &jn, &jd);
@@ -97,11 +101,11 @@ int eXosip_insubscription_remove (int did)
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No incoming subscription here?\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
-    REMOVE_ELEMENT (eXosip.j_notifies, jn);
-    eXosip_notify_free (jn);
-    return 0;
+  REMOVE_ELEMENT (eXosip.j_notifies, jn);
+  eXosip_notify_free (jn);
+  return OSIP_SUCCESS;
 }
 
 int
@@ -114,6 +118,9 @@ eXosip_insubscription_build_answer (int tid, int status, osip_message_t ** answe
 
   *answer = NULL;
 
+  if (tid <= 0)
+    return OSIP_BADPARAMETER;
+
   if (tid > 0)
     {
       _eXosip_insubscription_transaction_find (tid, &jn, &jd, &tr);
@@ -123,7 +130,7 @@ eXosip_insubscription_build_answer (int tid, int status, osip_message_t ** answe
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No incoming subscription here?\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   if (status < 101 || status > 699)
@@ -131,7 +138,7 @@ eXosip_insubscription_build_answer (int tid, int status, osip_message_t ** answe
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: wrong status code (101<status<699)\n"));
-      return -1;
+      return OSIP_BADPARAMETER;
     }
 
   if (jd != NULL)
@@ -146,7 +153,7 @@ eXosip_insubscription_build_answer (int tid, int status, osip_message_t ** answe
       OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_ERROR, NULL,
                               "ERROR: Could not create response for %s\n",
                               tr->orig_request->sip_method));
-      return -1;
+      return i;
     }
 
   if (status >= 200 && status <= 299)
@@ -155,7 +162,7 @@ eXosip_insubscription_build_answer (int tid, int status, osip_message_t ** answe
   if (status < 300)
     i = complete_answer_that_establish_a_dialog (*answer, tr->orig_request);
 
-  return 0;
+  return i;
 }
 
 int
@@ -167,6 +174,9 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
   osip_transaction_t *tr = NULL;
   osip_event_t *evt_answer;
 
+  if (tid <= 0)
+    return OSIP_BADPARAMETER;
+
   if (tid > 0)
     {
       _eXosip_insubscription_transaction_find (tid, &jn, &jd, &tr);
@@ -178,23 +188,19 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No incoming subscription here?\n"));
       osip_message_free (answer);
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   if (answer == NULL)
     {
       if (0 == osip_strcasecmp (tr->orig_request->sip_method, "SUBSCRIBE"))
         {
-          if (status >= 101 && status <= 199)
-            {
-          } else if (status >= 300 && status <= 699)
-            {
-          } else
+          if (status >= 200 && status <= 299)
             {
               OSIP_TRACE (osip_trace
                           (__FILE__, __LINE__, OSIP_ERROR, NULL,
                            "eXosip: Wrong parameter?\n"));
-              return -1;
+              return OSIP_BADPARAMETER;
             }
         }
     }
@@ -206,7 +212,7 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: transaction already answered\n"));
       osip_message_free (answer);
-      return -1;
+      return OSIP_WRONG_STATE;
     }
 
   if (answer == NULL)
@@ -222,7 +228,7 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
               OSIP_TRACE (osip_trace
                           (__FILE__, __LINE__, OSIP_ERROR, NULL,
                            "eXosip: cannot send response!\n"));
-              return -1;
+              return i;
             }
       } else
         {
@@ -230,9 +236,9 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
           OSIP_TRACE (osip_trace
                       (__FILE__, __LINE__, OSIP_ERROR, NULL,
                        "eXosip: a response must be given!\n"));
-          return -1;
+          return OSIP_BADPARAMETER;
         }
-      return 0;
+      return OSIP_SUCCESS;
   } else
     {
       i = 0;
@@ -255,12 +261,12 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
                       (__FILE__, __LINE__, OSIP_ERROR, NULL,
                        "eXosip: wrong status code (101<status<699)\n"));
           osip_message_free (answer);
-          return -1;
+          return OSIP_BADPARAMETER;
         }
       if (i != 0)
         {
           osip_message_free (answer);
-          return -1;
+          return i;
         }
     }
 
@@ -270,7 +276,7 @@ eXosip_insubscription_send_answer (int tid, int status, osip_message_t * answer)
   osip_transaction_add_event (tr, evt_answer);
   eXosip_update ();
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -288,6 +294,10 @@ eXosip_insubscription_build_notify (int did, int subscription_status,
   int i;
 
   *request = NULL;
+
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
+
   if (did > 0)
     {
       eXosip_notify_dialog_find (did, &jn, &jd);
@@ -297,7 +307,7 @@ eXosip_insubscription_build_notify (int did, int subscription_status,
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No incoming subscription here?\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   i = eXosip_insubscription_build_request (did, "NOTIFY", request);
@@ -335,7 +345,7 @@ eXosip_insubscription_build_notify (int did, int subscription_status,
   osip_message_set_header (*request, "Subscription-State", subscription_state);
 #endif
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -351,7 +361,10 @@ eXosip_insubscription_build_request (int did, const char *method,
 
   *request = NULL;
   if (method == NULL || method[0] == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
+
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
 
   if (did > 0)
     {
@@ -362,7 +375,7 @@ eXosip_insubscription_build_request (int did, const char *method,
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No incoming subscription here?\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   transaction = NULL;
@@ -373,7 +386,7 @@ eXosip_insubscription_build_request (int did, const char *method,
           transaction->state != NIST_TERMINATED &&
           transaction->state != NICT_COMPLETED &&
           transaction->state != NIST_COMPLETED)
-        return -1;
+        return OSIP_WRONG_STATE;
     }
 
   transport = NULL;
@@ -392,9 +405,9 @@ eXosip_insubscription_build_request (int did, const char *method,
       _eXosip_build_request_within_dialog (request, method, jd->d_dialog,
                                            transport);
   if (i != 0)
-    return -2;
+    return i;
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -408,7 +421,13 @@ eXosip_insubscription_send_request (int did, osip_message_t * request)
   int i;
 
   if (request == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
+
+  if (did <= 0)
+    {
+      osip_message_free (request);
+      return OSIP_BADPARAMETER;
+    }
 
   if (did > 0)
     {
@@ -420,7 +439,7 @@ eXosip_insubscription_send_request (int did, osip_message_t * request)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No incoming subscription here?\n"));
       osip_message_free (request);
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   transaction = NULL;
@@ -433,7 +452,7 @@ eXosip_insubscription_send_request (int did, osip_message_t * request)
           transaction->state != NIST_COMPLETED)
         {
           osip_message_free (request);
-          return -1;
+          return OSIP_WRONG_STATE;
         }
       transaction = NULL;
     }
@@ -442,7 +461,7 @@ eXosip_insubscription_send_request (int did, osip_message_t * request)
   if (i != 0)
     {
       osip_message_free (request);
-      return -1;
+      return i;
     }
 
   osip_list_add (jd->d_out_trs, transaction, 0);
@@ -454,7 +473,7 @@ eXosip_insubscription_send_request (int did, osip_message_t * request)
                                       __eXosip_new_jinfo (NULL, jd, NULL, jn));
   osip_transaction_add_event (transaction, sipevent);
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -471,11 +490,11 @@ _eXosip_insubscription_send_request_with_credential (eXosip_notify_t * jn,
   int i;
 
   if (jn == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (jd != NULL)
     {
       if (jd->d_out_trs == NULL)
-        return -1;
+        return OSIP_BADPARAMETER;
     }
 
   if (out_tr == NULL)
@@ -485,15 +504,15 @@ _eXosip_insubscription_send_request_with_credential (eXosip_notify_t * jn,
 
   if (out_tr == NULL
       || out_tr->orig_request == NULL || out_tr->last_response == NULL)
-    return -1;
+    return OSIP_NOTFOUND;
 
-  osip_message_clone (out_tr->orig_request, &msg);
-  if (msg == NULL)
+  i = osip_message_clone (out_tr->orig_request, &msg);
+  if (i != 0)
     {
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: could not clone msg for authentication\n"));
-      return -1;
+      return i;
     }
 
   via = (osip_via_t *) osip_list_get (&msg->vias, 0);
@@ -503,29 +522,36 @@ _eXosip_insubscription_send_request_with_credential (eXosip_notify_t * jn,
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: missing via or cseq header\n"));
-      return -1;
+      return OSIP_SYNTAXERROR;
     }
 
   /* increment cseq */
   cseq = atoi (msg->cseq->number);
   osip_free (msg->cseq->number);
   msg->cseq->number = strdup_printf ("%i", cseq + 1);
+  if (msg->cseq->number == NULL)
+    {
+      osip_message_free (msg);
+      return OSIP_NOMEM;
+    }
+
   if (jd != NULL && jd->d_dialog != NULL)
     {
       jd->d_dialog->local_cseq++;
     }
 
-  i = eXosip_update_top_via(msg);
-  if (i!=0)
+  i = eXosip_update_top_via (msg);
+  if (i != 0)
     {
       osip_message_free (msg);
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: unsupported protocol\n"));
-      return -1;
+      return i;
     }
 
-  if (out_tr->last_response->status_code==401 || out_tr->last_response->status_code==407)
+  if (out_tr->last_response->status_code == 401
+      || out_tr->last_response->status_code == 407)
     eXosip_add_authentication_information (msg, out_tr->last_response);
   else
     eXosip_add_authentication_information (msg, NULL);
@@ -537,7 +563,7 @@ _eXosip_insubscription_send_request_with_credential (eXosip_notify_t * jn,
   if (i != 0)
     {
       osip_message_free (msg);
-      return -1;
+      return i;
     }
 
   /* add the new tr for the current dialog */
@@ -550,169 +576,186 @@ _eXosip_insubscription_send_request_with_credential (eXosip_notify_t * jn,
 
   eXosip_update ();             /* fixed? */
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 _eXosip_insubscription_auto_send_notify (int did,
-                          int subscription_status, int subscription_reason)
+                                         int subscription_status,
+                                         int subscription_reason)
 {
-	osip_message_t *notify;
-	int i;
-	char xml[4096];
-	char *entity;
-	eXosip_call_t *jc;
-	eXosip_dialog_t *jd;
+  osip_message_t *notify;
+  int i;
+  char xml[4096];
+  char *entity;
+  eXosip_call_t *jc;
+  eXosip_dialog_t *jd;
 
-	i = eXosip_insubscription_build_notify (did, subscription_status,
-										  subscription_reason, &notify);
-	if (i != 0)
-	{
-		return -1;
-	}
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
 
-	/* build dialog xml state */
-	memset(xml, 0, sizeof(xml));
+  i = eXosip_insubscription_build_notify (did, subscription_status,
+                                          subscription_reason, &notify);
+  if (i != 0)
+    {
+      return i;
+    }
 
-	osip_uri_to_str(notify->from->url , &entity);
-	if (entity==NULL)
-		return -1;
-	snprintf(xml, sizeof(xml),
-		   "<?xml version=\"1.0\"?>" "\r\n"
-		   "<dialog-info xmlns=\"urn:ietf:params:xml:ns:dialog-info\"" "\r\n"
-		   "	version=\"2\" state=\"full\"" "\r\n"
-		   "	entity=\"%s\">" "\r\n",
-		   entity);
-	osip_free(entity);
+  /* build dialog xml state */
+  memset (xml, 0, sizeof (xml));
 
-	/* loop over all jc/jd */
-	for (jc = eXosip.j_calls; jc != NULL; jc = jc->next)
-	{
-		for (jd = jc->c_dialogs; jd != NULL; jd = jd->next)
-		{
-			if (jd->d_dialog == NULL)     /* finished call */
-			{
-			}
-			else
-			{
-				char tmp_dialog[2048];
-				char direction[20];
-				char dlg_state[20];
-				char *remote_uri=NULL;
+  i = osip_uri_to_str (notify->from->url, &entity);
+  if (i != 0 || entity == NULL)
+    {
+      osip_message_free (notify);
+      return i;
+    }
+  snprintf (xml, sizeof (xml),
+            "<?xml version=\"1.0\"?>" "\r\n"
+            "<dialog-info xmlns=\"urn:ietf:params:xml:ns:dialog-info\"" "\r\n"
+            "	version=\"2\" state=\"full\"" "\r\n"
+            "	entity=\"%s\">" "\r\n", entity);
+  osip_free (entity);
 
-				if (jd->d_dialog->type == CALLER)
-					strcpy(direction, "initiator");
-				else
-					strcpy(direction, "recipient");
-				if (jd->d_dialog->state == DIALOG_CONFIRMED)
-					strcpy(dlg_state, "confirmed");
-				else
-					strcpy(dlg_state, "early");
+  /* loop over all jc/jd */
+  for (jc = eXosip.j_calls; jc != NULL; jc = jc->next)
+    {
+      for (jd = jc->c_dialogs; jd != NULL; jd = jd->next)
+        {
+          if (jd->d_dialog == NULL)     /* finished call */
+            {
+          } else
+            {
+              char tmp_dialog[2048];
+              char direction[20];
+              char dlg_state[20];
+              char *remote_uri = NULL;
 
-				if (jd->d_dialog->remote_uri!=NULL
-					&&jd->d_dialog->remote_uri->url!=NULL)
-				{
-					osip_uri_to_str(jd->d_dialog->remote_uri->url, &remote_uri);
-				}
-				if (remote_uri!=NULL)
-				{
-					/* add dialog info */
-					snprintf(tmp_dialog, sizeof(tmp_dialog),
-						"	<dialog id=\"%s\" call-id=\"%s\"" "\r\n"
-						"		local-tag=\"%s\" remote-tag=\"%s\"" "\r\n"
-						"		direction=\"%s\">" "\r\n"
-						"		<state>%s</state>" "\r\n"
-						"		<remote>" "\r\n"
-						"			<identity>%s</identity>" "\r\n"
-						"		</remote>" "\r\n"
-						"	</dialog>" "\r\n",
-						jd->d_dialog->call_id,
-						jd->d_dialog->call_id,
-						jd->d_dialog->local_tag,
-						jd->d_dialog->remote_tag,
-						direction,
-						dlg_state,
-						remote_uri);
-					strcat(xml, tmp_dialog);
-				}
-			}
-		}
-	}
-	strcat(xml, "</dialog-info>" "\r\n");
-	osip_message_set_content_type (notify, "application/dialog-info+xml");
-	osip_message_set_body (notify, xml, strlen(xml));
+              if (jd->d_dialog->type == CALLER)
+                strcpy (direction, "initiator");
+              else
+                strcpy (direction, "recipient");
+              if (jd->d_dialog->state == DIALOG_CONFIRMED)
+                strcpy (dlg_state, "confirmed");
+              else
+                strcpy (dlg_state, "early");
 
-	return eXosip_insubscription_send_request (did, notify);
+              if (jd->d_dialog->remote_uri != NULL
+                  && jd->d_dialog->remote_uri->url != NULL)
+                {
+                  osip_uri_to_str (jd->d_dialog->remote_uri->url, &remote_uri);
+                }
+              if (remote_uri != NULL)
+                {
+                  /* add dialog info */
+                  snprintf (tmp_dialog, sizeof (tmp_dialog),
+                            "	<dialog id=\"%s\" call-id=\"%s\"" "\r\n"
+                            "		local-tag=\"%s\" remote-tag=\"%s\""
+                            "\r\n" "		direction=\"%s\">"
+                            "\r\n"
+                            "		<state>%s</state>"
+                            "\r\n"
+                            "		<remote>"
+                            "\r\n"
+                            "			<identity>%s</identity>"
+                            "\r\n"
+                            "		</remote>"
+                            "\r\n"
+                            "	</dialog>"
+                            "\r\n",
+                            jd->
+                            d_dialog->
+                            call_id,
+                            jd->
+                            d_dialog->
+                            call_id,
+                            jd->
+                            d_dialog->
+                            local_tag,
+                            jd->
+                            d_dialog->
+                            remote_tag, direction, dlg_state, remote_uri);
+                  strcat (xml, tmp_dialog);
+                }
+            }
+        }
+    }
+  strcat (xml, "</dialog-info>" "\r\n");
+  osip_message_set_content_type (notify, "application/dialog-info+xml");
+  osip_message_set_body (notify, xml, strlen (xml));
+
+  return eXosip_insubscription_send_request (did, notify);
 }
 
 int
-eXosip_insubscription_automatic(eXosip_event_t *evt)
+eXosip_insubscription_automatic (eXosip_event_t * evt)
 {
-	eXosip_dialog_t *jd = NULL;
-	eXosip_notify_t *jn = NULL;
+  eXosip_dialog_t *jd = NULL;
+  eXosip_notify_t *jn = NULL;
 
-	osip_header_t *event_header;
-	if (evt->did<=0 || evt->nid<=0)
-		return -1;
-	if (evt->request==NULL)
-		return -1;
+  osip_header_t *event_header;
+  if (evt->did <= 0 || evt->nid <= 0)
+    return OSIP_BADPARAMETER;
+  if (evt->request == NULL)
+    return OSIP_BADPARAMETER;
 
-	eXosip_notify_dialog_find (evt->did, &jn, &jd);
-	if (jd == NULL || jn == NULL)
-	{
-		OSIP_TRACE (osip_trace
-				  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-				   "eXosip: No incoming subscription here?\n"));
-		return -1;
-	}
+  eXosip_notify_dialog_find (evt->did, &jn, &jd);
+  if (jd == NULL || jn == NULL)
+    {
+      OSIP_TRACE (osip_trace
+                  (__FILE__, __LINE__, OSIP_ERROR, NULL,
+                   "eXosip: No incoming subscription here?\n"));
+      return OSIP_NOTFOUND;
+    }
 
-	osip_message_header_get_byname (evt->request , "event",
-                                    0, &event_header);
-	if (event_header == NULL || event_header->hvalue == NULL)
-	{
-		eXosip_insubscription_send_answer (evt->tid, 400, NULL);
-		return 0;
-	}
+  osip_message_header_get_byname (evt->request, "event", 0, &event_header);
+  if (event_header == NULL || event_header->hvalue == NULL)
+    {
+      eXosip_insubscription_send_answer (evt->tid, 400, NULL);
+      return OSIP_SUCCESS;
+    }
 
-	/* this event should be handled internally */
-	if (osip_strcasecmp(event_header->hvalue, "dialog") == 0)
-	{
-		/* send 200 ok to SUBSCRIBEs */
+  /* this event should be handled internally */
+  if (osip_strcasecmp (event_header->hvalue, "dialog") == 0)
+    {
+      /* send 200 ok to SUBSCRIBEs */
 
-		if (evt->type == EXOSIP_IN_SUBSCRIPTION_NEW)
-		{
-			osip_message_t *answer;
-			int i;
+      if (evt->type == EXOSIP_IN_SUBSCRIPTION_NEW)
+        {
+          osip_message_t *answer;
+          int i;
 
-			i = eXosip_insubscription_build_answer (evt->tid, 202, &answer);
-			if (i == 0)
-			{
-				i = eXosip_insubscription_send_answer (evt->tid, 202, answer);
-			}
-			if (i != 0)
-			{
-				i = eXosip_insubscription_send_answer (evt->tid, 400, NULL);
-				return 0;
-			}
+          i = eXosip_insubscription_build_answer (evt->tid, 202, &answer);
+          if (i == 0)
+            {
+              i = eXosip_insubscription_send_answer (evt->tid, 202, answer);
+            }
+          if (i != 0)
+            {
+              i = eXosip_insubscription_send_answer (evt->tid, 400, NULL);
+              return OSIP_SUCCESS;
+            }
 
-			/* send initial notify */
-			i = _eXosip_insubscription_auto_send_notify(evt->did , EXOSIP_SUBCRSTATE_ACTIVE, PROBATION);
-			if (i != 0)
-			{
-				/* delete subscription... */
-				return 0;
-			}
-		}
-	}
-	else
-	{
-		if (evt->type == EXOSIP_IN_SUBSCRIPTION_NEW)
-		{
-		  eXosip_insubscription_send_answer (evt->tid, 489, NULL);
-		}
-	}
+          /* send initial notify */
+          i =
+            _eXosip_insubscription_auto_send_notify (evt->did,
+                                                     EXOSIP_SUBCRSTATE_ACTIVE,
+                                                     PROBATION);
+          if (i != 0)
+            {
+              /* delete subscription... */
+              return OSIP_SUCCESS;
+            }
+        }
+  } else
+    {
+      if (evt->type == EXOSIP_IN_SUBSCRIPTION_NEW)
+        {
+          eXosip_insubscription_send_answer (evt->tid, 489, NULL);
+        }
+    }
 
-	return 0;
+  return OSIP_SUCCESS;
 }
 
 #endif
