@@ -36,22 +36,22 @@ eXosip_options_build_request (osip_message_t ** options, const char *to,
 
   *options = NULL;
   if (to != NULL && *to == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
   if (from != NULL && *from == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
   if (route != NULL && *route == '\0')
     route = NULL;
 
   i = generating_request_out_of_dialog (options, "OPTIONS", to, "UDP", from,
                                         route);
   if (i != 0)
-    return -1;
+    return i;
 
   /* after this delay, we should send a CANCEL */
   osip_message_set_expires (*options, "120");
 
   /* osip_message_set_organization(*invite, "Jack's Org"); */
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -65,10 +65,10 @@ eXosip_options_send_request (osip_message_t * options)
   if (i != 0)
     {
       osip_message_free (options);
-      return -1;
+      return i;
     }
 
-  osip_list_add (eXosip.j_transactions, transaction, 0);
+  osip_list_add (&eXosip.j_transactions, transaction, 0);
 
   sipevent = osip_new_outgoing_sipmessage (options);
   sipevent->transactionid = transaction->transactionid;
@@ -78,16 +78,22 @@ eXosip_options_send_request (osip_message_t * options)
   osip_transaction_add_event (transaction, sipevent);
 
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 eXosip_options_build_answer (int tid, int status, osip_message_t ** answer)
 {
   osip_transaction_t *tr = NULL;
-  int i = -1;
+  int i;
 
   *answer = NULL;
+
+  if (tid <= 0)
+    return OSIP_BADPARAMETER;
+  if (status < 200 || status > 699)
+    return OSIP_BADPARAMETER;
+
   if (tid > 0)
     {
       eXosip_transaction_find (tid, &tr);
@@ -97,34 +103,18 @@ eXosip_options_build_answer (int tid, int status, osip_message_t ** answer)
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No call here?\n"));
-      return -1;
-    }
-  if (status > 100 && status < 200)
-    {
-#if 0
-      /* TODO: not implemented */
-      i = _eXosip_build_response_default (response, NULL, code, tr->orig_request);
-#endif
-      OSIP_TRACE (osip_trace
-                  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-                   "eXosip: status code 1xx for options not implemented (use 200<status<=699)\n"));
-      return -1;
-  } else if (status > 199 && status < 300)
-    {
-      i = _eXosip_build_response_default (answer, NULL, status, tr->orig_request);
-  } else if (status > 300 && status <= 699)
-    {
-      i = _eXosip_build_response_default (answer, NULL, status, tr->orig_request);
-  } else
-    {
-      OSIP_TRACE (osip_trace
-                  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-                   "eXosip: wrong status code (200<status<=699)\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
+
+  i = -1;
+  if (status > 199 && status < 300)
+    i = _eXosip_build_response_default (answer, NULL, status, tr->orig_request);
+  else if (status > 300 && status <= 699)
+    i = _eXosip_build_response_default (answer, NULL, status, tr->orig_request);
   if (i != 0)
-    return -1;
-  return 0;
+    return i;
+
+  return OSIP_SUCCESS;
 }
 
 int
@@ -134,6 +124,13 @@ eXosip_options_send_answer (int tid, int status, osip_message_t * answer)
   osip_event_t *evt_answer;
   int i = -1;
 
+  if (tid <= 0)
+    return OSIP_BADPARAMETER;
+  if (status <= 100 || status > 699)
+    return OSIP_BADPARAMETER;
+  if (answer == NULL && status > 100 && status < 200)
+    return OSIP_BADPARAMETER;
+
   if (tid > 0)
     {
       eXosip_transaction_find (tid, &tr);
@@ -144,7 +141,7 @@ eXosip_options_send_answer (int tid, int status, osip_message_t * answer)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No OPTIONS transaction found\n"));
       osip_message_free (answer);
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   /* is the transaction already answered? */
@@ -154,42 +151,20 @@ eXosip_options_send_answer (int tid, int status, osip_message_t * answer)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: transaction already answered\n"));
       osip_message_free (answer);
-      return -1;
+      return OSIP_WRONG_STATE;
     }
 
   if (answer == NULL)
     {
-      if (status > 100 && status < 200)
-        {
-#if 0
-          /* TODO: not implemented */
-          i =
-            _eXosip_build_response_default (response, NULL, code,
+      i = -1;
+      if (status > 199 && status < 300)
+        i = _eXosip_build_response_default (&answer, NULL, status,
                                             tr->orig_request);
-#endif
-          OSIP_TRACE (osip_trace
-                      (__FILE__, __LINE__, OSIP_ERROR, NULL,
-                       "eXosip: status code 1xx for options not implemented (use 200<status<=699)\n"));
-          return -1;
-      } else if (status > 199 && status < 300)
-        {
-          i =
-            _eXosip_build_response_default (&answer, NULL, status,
+      else if (status > 300 && status <= 699)
+        i = _eXosip_build_response_default (&answer, NULL, status,
                                             tr->orig_request);
-      } else if (status > 300 && status <= 699)
-        {
-          i =
-            _eXosip_build_response_default (&answer, NULL, status,
-                                            tr->orig_request);
-      } else
-        {
-          OSIP_TRACE (osip_trace
-                      (__FILE__, __LINE__, OSIP_ERROR, NULL,
-                       "eXosip: wrong status code (200<status<=699)\n"));
-          return -1;
-        }
       if (i != 0)
-        return -1;
+        return i;
     }
 
   evt_answer = osip_new_outgoing_sipmessage (answer);
@@ -197,7 +172,7 @@ eXosip_options_send_answer (int tid, int status, osip_message_t * answer)
 
   osip_transaction_add_event (tr, evt_answer);
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #endif
