@@ -30,7 +30,8 @@ extern eXosip_t eXosip;
 
 int
 _eXosip_subscribe_transaction_find (int tid, eXosip_subscribe_t ** js,
-				    eXosip_dialog_t ** jd, osip_transaction_t ** tr)
+                                    eXosip_dialog_t ** jd,
+                                    osip_transaction_t ** tr)
 {
   for (*js = eXosip.j_subscribes; *js != NULL; *js = (*js)->next)
     {
@@ -38,13 +39,13 @@ _eXosip_subscribe_transaction_find (int tid, eXosip_subscribe_t ** js,
         {
           *tr = (*js)->s_inc_tr;
           *jd = (*js)->s_dialogs;
-          return 0;
+          return OSIP_SUCCESS;
         }
       if ((*js)->s_out_tr != NULL && (*js)->s_out_tr->transactionid == tid)
         {
           *tr = (*js)->s_out_tr;
           *jd = (*js)->s_dialogs;
-          return 0;
+          return OSIP_SUCCESS;
         }
       for (*jd = (*js)->s_dialogs; *jd != NULL; *jd = (*jd)->next)
         {
@@ -58,7 +59,7 @@ _eXosip_subscribe_transaction_find (int tid, eXosip_subscribe_t ** js,
               if (transaction != NULL && transaction->transactionid == tid)
                 {
                   *tr = transaction;
-                  return 0;
+                  return OSIP_SUCCESS;
                 }
               pos++;
             }
@@ -71,7 +72,7 @@ _eXosip_subscribe_transaction_find (int tid, eXosip_subscribe_t ** js,
               if (transaction != NULL && transaction->transactionid == tid)
                 {
                   *tr = transaction;
-                  return 0;
+                  return OSIP_SUCCESS;
                 }
               pos++;
             }
@@ -79,14 +80,18 @@ _eXosip_subscribe_transaction_find (int tid, eXosip_subscribe_t ** js,
     }
   *jd = NULL;
   *js = NULL;
-  return -1;
+  return OSIP_NOTFOUND;
 }
 
-int eXosip_subscribe_remove (int did)
+int
+eXosip_subscribe_remove (int did)
 {
   eXosip_dialog_t *jd = NULL;
   eXosip_subscribe_t *js = NULL;
 
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
+
   if (did > 0)
     {
       eXosip_subscribe_dialog_find (did, &js, &jd);
@@ -96,11 +101,11 @@ int eXosip_subscribe_remove (int did)
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No outgoing subscription here?\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
-    REMOVE_ELEMENT (eXosip.j_subscribes, js);
-    eXosip_subscribe_free (js);
-    return 0;
+  REMOVE_ELEMENT (eXosip.j_subscribes, js);
+  eXosip_subscribe_free (js);
+  return OSIP_SUCCESS;
 }
 
 int
@@ -114,38 +119,39 @@ eXosip_subscribe_build_initial_request (osip_message_t ** sub, const char *to,
 
   *sub = NULL;
   if (to == NULL || *to == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
   if (from == NULL || *from == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
   if (event == NULL || *event == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
   if (route == NULL || *route == '\0')
     route = NULL;
 
   i = osip_to_init (&_to);
   if (i != 0)
-    return -1;
+    return i;
 
   i = osip_to_parse (_to, to);
   if (i != 0)
     {
       osip_to_free (_to);
-      return -1;
+      return i;
     }
 
-  i = generating_request_out_of_dialog (sub, "SUBSCRIBE", to, eXosip.transport, from,
-                                            route);
+  i =
+    generating_request_out_of_dialog (sub, "SUBSCRIBE", to, eXosip.transport, from,
+                                      route);
   osip_to_free (_to);
   if (i != 0)
-    return -1;
-  _eXosip_dialog_add_contact(*sub, NULL);
+    return i;
+  _eXosip_dialog_add_contact (*sub, NULL);
 
   snprintf (tmp, 10, "%i", expires);
   osip_message_set_expires (*sub, tmp);
 
   osip_message_set_header (*sub, "Event", event);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -163,7 +169,7 @@ eXosip_subscribe_send_initial_request (osip_message_t * subscribe)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: cannot subscribe."));
       osip_message_free (subscribe);
-      return -1;
+      return i;
     }
 
   i = _eXosip_transaction_init (&transaction, NICT, eXosip.j_osip, subscribe);
@@ -171,9 +177,10 @@ eXosip_subscribe_send_initial_request (osip_message_t * subscribe)
     {
       eXosip_subscribe_free (js);
       osip_message_free (subscribe);
-      return -1;
+      return i;
     }
 
+  js->s_reg_period = 3600;
   _eXosip_subscribe_set_refresh_interval (js, subscribe);
   js->s_out_tr = transaction;
 
@@ -201,6 +208,10 @@ eXosip_subscribe_build_refresh_request (int did, osip_message_t ** sub)
   int i;
 
   *sub = NULL;
+
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
+
   if (did > 0)
     {
       eXosip_subscribe_dialog_find (did, &js, &jd);
@@ -210,7 +221,7 @@ eXosip_subscribe_build_refresh_request (int did, osip_message_t ** sub)
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No subscribe here?\n"));
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   transaction = NULL;
@@ -222,7 +233,7 @@ eXosip_subscribe_build_refresh_request (int did, osip_message_t ** sub)
           transaction->state != NIST_TERMINATED &&
           transaction->state != NICT_COMPLETED &&
           transaction->state != NIST_COMPLETED)
-        return -1;
+        return OSIP_WRONG_STATE;
     }
 
   transport = NULL;
@@ -240,12 +251,12 @@ eXosip_subscribe_build_refresh_request (int did, osip_message_t ** sub)
                                            transport);
 
   if (i != 0)
-    return -2;
+    return i;
 
 
-  eXosip_add_authentication_information(*sub, NULL);
+  eXosip_add_authentication_information (*sub, NULL);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -258,6 +269,9 @@ eXosip_subscribe_send_refresh_request (int did, osip_message_t * sub)
   osip_event_t *sipevent;
   int i;
 
+  if (did <= 0)
+    return OSIP_BADPARAMETER;
+
   if (did > 0)
     {
       eXosip_subscribe_dialog_find (did, &js, &jd);
@@ -268,7 +282,7 @@ eXosip_subscribe_send_refresh_request (int did, osip_message_t * sub)
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: No subscribe here?\n"));
       osip_message_free (sub);
-      return -1;
+      return OSIP_NOTFOUND;
     }
 
   transaction = NULL;
@@ -282,7 +296,7 @@ eXosip_subscribe_send_refresh_request (int did, osip_message_t * sub)
           transaction->state != NIST_COMPLETED)
         {
           osip_message_free (sub);
-          return -1;
+          return OSIP_WRONG_STATE;
         }
       transaction = NULL;
     }
@@ -293,9 +307,10 @@ eXosip_subscribe_send_refresh_request (int did, osip_message_t * sub)
   if (i != 0)
     {
       osip_message_free (sub);
-      return -2;
+      return i;
     }
 
+  js->s_reg_period = 3600;
   _eXosip_subscribe_set_refresh_interval (js, sub);
   osip_list_add (jd->d_out_trs, transaction, 0);
 
@@ -306,69 +321,81 @@ eXosip_subscribe_send_refresh_request (int did, osip_message_t * sub)
                                       __eXosip_new_jinfo (NULL, jd, js, NULL));
   osip_transaction_add_event (transaction, sipevent);
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
-_eXosip_subscribe_automatic_refresh(eXosip_subscribe_t * js,
-									eXosip_dialog_t * jd,
-									osip_transaction_t *out_tr)
+_eXosip_subscribe_automatic_refresh (eXosip_subscribe_t * js,
+                                     eXosip_dialog_t * jd,
+                                     osip_transaction_t * out_tr)
 {
-	osip_message_t *sub=NULL;
-	osip_header_t *expires;
-	int i;
-	if (js==NULL || jd==NULL || out_tr==NULL || out_tr->orig_request==NULL)
-		return -1;
+  osip_message_t *sub = NULL;
+  osip_header_t *expires;
+  int i;
+  if (js == NULL || jd == NULL || out_tr == NULL || out_tr->orig_request == NULL)
+    return OSIP_BADPARAMETER;
 
-	i = eXosip_subscribe_build_refresh_request (jd->d_id, &sub);
-	if (i != 0)
-		return -1;
+  i = eXosip_subscribe_build_refresh_request (jd->d_id, &sub);
+  if (i != 0)
+    return i;
 
-	i = osip_message_get_expires (out_tr->orig_request, 0, &expires);
-	if (expires != NULL && expires->hvalue != NULL)
-	{
-		osip_message_set_expires (sub, expires->hvalue);
-	}
+  i = osip_message_get_expires (out_tr->orig_request, 0, &expires);
+  if (expires != NULL && expires->hvalue != NULL)
+    {
+      osip_message_set_expires (sub, expires->hvalue);
+    }
 
-	{
-		int pos=0;
-		osip_accept_t *_accept = NULL;
+  {
+    int pos = 0;
+    osip_accept_t *_accept = NULL;
 
-		i = osip_message_get_accept (out_tr->orig_request, pos, &_accept);
-		while (i == 0 && _accept != NULL)
-		  {
-			osip_accept_t *_accept2;
+    i = osip_message_get_accept (out_tr->orig_request, pos, &_accept);
+    while (i >= 0 && _accept != NULL)
+      {
+        osip_accept_t *_accept2;
 
-			i = osip_accept_clone (_accept, &_accept2);
-			if (i != 0)
-			  {
-				OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_ERROR, NULL,
-										"Error in Accept header\n"));
-				break;
-			  }
-			osip_list_add (&sub->accepts, _accept2, -1);
-			_accept = NULL;
-			pos++;
-			i = osip_message_get_accept (out_tr->orig_request, pos, &_accept);
-		  }
-	}
+        i = osip_accept_clone (_accept, &_accept2);
+        if (i != 0)
+          {
+            OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_ERROR, NULL,
+                                    "Error in Accept header\n"));
+            break;
+          }
+        osip_list_add (&sub->accepts, _accept2, -1);
+        _accept = NULL;
+        pos++;
+        i = osip_message_get_accept (out_tr->orig_request, pos, &_accept);
+      }
+  }
 
-	{
-		osip_header_t *hdr=NULL;
-		i = osip_message_header_get_byname (out_tr->orig_request, "Event", 0, &hdr);
-		if (hdr==NULL || i<0)
-		{
-			OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_ERROR, NULL,
-										"Missing Event header\n"));
-			osip_message_free(sub);
-			return -1;
-		}
+  {
+    int pos = 0;
+    osip_header_t *_event = NULL;
 
-		osip_message_set_header (sub, "Event", hdr->hvalue);
-	}
+    pos =
+      osip_message_header_get_byname (out_tr->orig_request, "Event", 0, &_event);
+    while (pos >= 0 && _event != NULL)
+      {
+        osip_header_t *_event2;
 
-	i = eXosip_subscribe_send_refresh_request (jd->d_id, sub);
-	return i;
+        i = osip_header_clone (_event, &_event2);
+        if (i != 0)
+          {
+            OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_ERROR, NULL,
+                                    "Error in Event header\n"));
+            break;
+          }
+        osip_list_add (&sub->headers, _event2, -1);
+        _event = NULL;
+        pos++;
+        pos =
+          osip_message_header_get_byname (out_tr->orig_request, "Event", pos,
+                                          &_event);
+      }
+  }
+
+  i = eXosip_subscribe_send_refresh_request (jd->d_id, sub);
+  return i;
 }
 
 int
@@ -385,11 +412,11 @@ _eXosip_subscribe_send_request_with_credential (eXosip_subscribe_t * js,
   int i;
 
   if (js == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (jd != NULL)
     {
       if (jd->d_out_trs == NULL)
-        return -1;
+        return OSIP_BADPARAMETER;
     }
 
   if (out_tr == NULL)
@@ -399,25 +426,25 @@ _eXosip_subscribe_send_request_with_credential (eXosip_subscribe_t * js,
 
   if (out_tr == NULL
       || out_tr->orig_request == NULL || out_tr->last_response == NULL)
-    return -1;
+    return OSIP_NOTFOUND;
 
-  osip_message_clone (out_tr->orig_request, &msg);
-  if (msg == NULL)
+  i = osip_message_clone (out_tr->orig_request, &msg);
+  if (i != 0)
     {
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: could not clone msg for authentication\n"));
-      return -1;
+      return i;
     }
 
   {
     osip_generic_param_t *tag = NULL;
-    
-    osip_to_get_tag(msg->to, &tag);
+
+    osip_to_get_tag (msg->to, &tag);
     if (NULL == tag && jd != NULL && jd->d_dialog != NULL
-	&& jd->d_dialog->remote_tag != NULL)
+        && jd->d_dialog->remote_tag != NULL)
       {
-	osip_to_set_tag(msg->to, osip_strdup(jd->d_dialog->remote_tag));
+        osip_to_set_tag (msg->to, osip_strdup (jd->d_dialog->remote_tag));
       }
   }
 
@@ -428,26 +455,29 @@ _eXosip_subscribe_send_request_with_credential (eXosip_subscribe_t * js,
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "eXosip: missing via or cseq header\n"));
-      return -1;
+      return OSIP_SYNTAXERROR;
     }
 
   /* increment cseq */
   cseq = atoi (msg->cseq->number);
   osip_free (msg->cseq->number);
   msg->cseq->number = strdup_printf ("%i", cseq + 1);
+  if (msg->cseq->number == NULL)
+    {
+      osip_message_free (msg);
+      return OSIP_NOMEM;
+    }
+
   if (jd != NULL && jd->d_dialog != NULL)
     {
       jd->d_dialog->local_cseq++;
     }
 
-  i = eXosip_update_top_via(msg);
-  if (i!=0)
+  i = eXosip_update_top_via (msg);
+  if (i != 0)
     {
       osip_message_free (msg);
-      OSIP_TRACE (osip_trace
-                  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-                   "eXosip: unsupported protocol\n"));
-      return -1;
+      return i;
     }
 
   eXosip_add_authentication_information (msg, out_tr->last_response);
@@ -458,13 +488,13 @@ _eXosip_subscribe_send_request_with_credential (eXosip_subscribe_t * js,
   if (i != 0)
     {
       osip_message_free (msg);
-      return -1;
+      return i;
     }
 
   if (out_tr == js->s_out_tr)
     {
       /* replace with the new tr */
-      osip_list_add (eXosip.j_transactions, js->s_out_tr, 0);
+      osip_list_add (&eXosip.j_transactions, js->s_out_tr, 0);
       js->s_out_tr = tr;
   } else
     {
@@ -479,7 +509,7 @@ _eXosip_subscribe_send_request_with_credential (eXosip_subscribe_t * js,
 
   eXosip_update ();             /* fixed? */
   __eXosip_wakeup ();
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #endif
