@@ -30,15 +30,18 @@ extern eXosip_t eXosip;
 int
 eXosip_call_find (int cid, eXosip_call_t ** jc)
 {
+  if (cid <= 0)
+    return OSIP_BADPARAMETER;
+
   for (*jc = eXosip.j_calls; *jc != NULL; *jc = (*jc)->next)
     {
       if ((*jc)->c_id == cid)
         {
-          return 0;
+          return OSIP_SUCCESS;
         }
     }
   *jc = NULL;
-  return -1;
+  return OSIP_NOTFOUND;
 }
 
 int
@@ -46,11 +49,11 @@ eXosip_call_init (eXosip_call_t ** jc)
 {
   *jc = (eXosip_call_t *) osip_malloc (sizeof (eXosip_call_t));
   if (*jc == NULL)
-    return -1;
+    return OSIP_NOMEM;
   memset (*jc, 0, sizeof (eXosip_call_t));
 
   (*jc)->c_id = -1;             /* make sure the eXosip_update will assign a valid id to the call */
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -91,14 +94,14 @@ eXosip_call_free (eXosip_call_t * jc)
 
   eXosip_dialog_t *jd;
 
-  if (jc->c_inc_tr!=NULL && jc->c_inc_tr->orig_request!=NULL
-	  && jc->c_inc_tr->orig_request->call_id!=NULL
-	  && jc->c_inc_tr->orig_request->call_id->number!=NULL)
-	  _eXosip_delete_nonce(jc->c_inc_tr->orig_request->call_id->number);
-  else if (jc->c_out_tr!=NULL && jc->c_out_tr->orig_request!=NULL
-	  && jc->c_out_tr->orig_request->call_id!=NULL
-	  && jc->c_out_tr->orig_request->call_id->number!=NULL)
-	  _eXosip_delete_nonce(jc->c_out_tr->orig_request->call_id->number);
+  if (jc->c_inc_tr != NULL && jc->c_inc_tr->orig_request != NULL
+      && jc->c_inc_tr->orig_request->call_id != NULL
+      && jc->c_inc_tr->orig_request->call_id->number != NULL)
+    _eXosip_delete_nonce (jc->c_inc_tr->orig_request->call_id->number);
+  else if (jc->c_out_tr != NULL && jc->c_out_tr->orig_request != NULL
+           && jc->c_out_tr->orig_request->call_id != NULL
+           && jc->c_out_tr->orig_request->call_id->number != NULL)
+    _eXosip_delete_nonce (jc->c_out_tr->orig_request->call_id->number);
 
   for (jd = jc->c_dialogs; jd != NULL; jd = jc->c_dialogs)
     {
@@ -109,9 +112,9 @@ eXosip_call_free (eXosip_call_t * jc)
   __eXosip_delete_jinfo (jc->c_inc_tr);
   __eXosip_delete_jinfo (jc->c_out_tr);
   if (jc->c_inc_tr != NULL)
-    osip_list_add (eXosip.j_transactions, jc->c_inc_tr, 0);
+    osip_list_add (&eXosip.j_transactions, jc->c_inc_tr, 0);
   if (jc->c_out_tr != NULL)
-    osip_list_add (eXosip.j_transactions, jc->c_out_tr, 0);
+    osip_list_add (&eXosip.j_transactions, jc->c_out_tr, 0);
 
   osip_free (jc);
 
