@@ -84,17 +84,17 @@ eXosip_notify_init (eXosip_notify_t ** jn, osip_message_t * inc_subscribe)
 {
   osip_contact_t *co;
 
-  *jn=NULL;
+  *jn = NULL;
   co = (osip_contact_t *) osip_list_get (&inc_subscribe->contacts, 0);
   if (co == NULL || co->url == NULL)
     return -1;
 
   *jn = (eXosip_notify_t *) osip_malloc (sizeof (eXosip_notify_t));
   if (*jn == NULL)
-    return -1;
+    return OSIP_NOMEM;
   memset (*jn, 0, sizeof (eXosip_notify_t));
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -104,14 +104,14 @@ eXosip_notify_free (eXosip_notify_t * jn)
 
   eXosip_dialog_t *jd;
 
-  if (jn->n_inc_tr!=NULL && jn->n_inc_tr->orig_request!=NULL
-	  && jn->n_inc_tr->orig_request->call_id!=NULL
-	  && jn->n_inc_tr->orig_request->call_id->number!=NULL)
-	  _eXosip_delete_nonce(jn->n_inc_tr->orig_request->call_id->number);
-  else if (jn->n_out_tr!=NULL && jn->n_out_tr->orig_request!=NULL
-	  && jn->n_out_tr->orig_request->call_id!=NULL
-	  && jn->n_out_tr->orig_request->call_id->number!=NULL)
-	  _eXosip_delete_nonce(jn->n_out_tr->orig_request->call_id->number);
+  if (jn->n_inc_tr != NULL && jn->n_inc_tr->orig_request != NULL
+      && jn->n_inc_tr->orig_request->call_id != NULL
+      && jn->n_inc_tr->orig_request->call_id->number != NULL)
+    _eXosip_delete_nonce (jn->n_inc_tr->orig_request->call_id->number);
+  else if (jn->n_out_tr != NULL && jn->n_out_tr->orig_request != NULL
+           && jn->n_out_tr->orig_request->call_id != NULL
+           && jn->n_out_tr->orig_request->call_id->number != NULL)
+    _eXosip_delete_nonce (jn->n_out_tr->orig_request->call_id->number);
 
   for (jd = jn->n_dialogs; jd != NULL; jd = jn->n_dialogs)
     {
@@ -122,9 +122,9 @@ eXosip_notify_free (eXosip_notify_t * jn)
   __eXosip_delete_jinfo (jn->n_inc_tr);
   __eXosip_delete_jinfo (jn->n_out_tr);
   if (jn->n_inc_tr != NULL)
-    osip_list_add (eXosip.j_transactions, jn->n_inc_tr, 0);
+    osip_list_add (&eXosip.j_transactions, jn->n_inc_tr, 0);
   if (jn->n_out_tr != NULL)
-    osip_list_add (eXosip.j_transactions, jn->n_out_tr, 0);
+    osip_list_add (&eXosip.j_transactions, jn->n_out_tr, 0);
   osip_free (jn);
 }
 
@@ -151,7 +151,7 @@ _eXosip_notify_set_refresh_interval (eXosip_notify_t * jn,
         jn->n_ss_expires = now + 600;
     }
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
