@@ -53,16 +53,16 @@ _eXosip_pub_update (eXosip_pub_t ** pub, osip_transaction_t * tr,
                 snprintf (jpub->p_sip_etag, 64, "%s", sip_etag->hvalue);
             }
           *pub = jpub;
-          return 0;
+          return OSIP_SUCCESS;
         }
     }
-  return -1;
+  return OSIP_NOTFOUND;
 }
 
 int
 _eXosip_pub_find_by_aor (eXosip_pub_t ** pub, const char *aor)
 {
-  eXosip_pub_t *jpub;  
+  eXosip_pub_t *jpub;
   *pub = NULL;
 
   for (jpub = eXosip.j_pub; jpub != NULL; jpub = jpub->next)
@@ -70,10 +70,10 @@ _eXosip_pub_find_by_aor (eXosip_pub_t ** pub, const char *aor)
       if (osip_strcasecmp (aor, jpub->p_aor) == 0)
         {
           *pub = jpub;
-          return 0;
+          return OSIP_SUCCESS;
         }
     }
-  return -1;
+  return OSIP_NOTFOUND;
 }
 
 int
@@ -81,18 +81,19 @@ _eXosip_pub_find_by_tid (eXosip_pub_t ** pjp, int tid)
 {
   eXosip_pub_t *pub = eXosip.j_pub;
 
+  *pjp = NULL;
   while (pub)
     {
       if (pub->p_last_tr && pub->p_last_tr->transactionid == tid)
         {
           *pjp = pub;
-          return 0;
+          return OSIP_SUCCESS;
         }
 
       pub = pub->next;
     }
 
-  return -1;
+  return OSIP_NOTFOUND;
 }
 
 int
@@ -108,7 +109,7 @@ _eXosip_pub_init (eXosip_pub_t ** pub, const char *aor, const char *exp)
 
   jpub = (eXosip_pub_t *) osip_malloc (sizeof (eXosip_pub_t));
   if (jpub == 0)
-    return -1;
+    return OSIP_NOMEM;
   memset (jpub, 0, sizeof (eXosip_pub_t));
   snprintf (jpub->p_aor, 256, "%s", aor);
 
@@ -116,7 +117,7 @@ _eXosip_pub_init (eXosip_pub_t ** pub, const char *aor, const char *exp)
   jpub->p_id = ++p_id;
 
   *pub = jpub;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -124,12 +125,12 @@ _eXosip_pub_free (eXosip_pub_t * pub)
 {
   if (pub->p_last_tr != NULL)
     {
-      if (pub->p_last_tr!=NULL && pub->p_last_tr->orig_request!=NULL
-	  && pub->p_last_tr->orig_request->call_id!=NULL
-	  && pub->p_last_tr->orig_request->call_id->number!=NULL)
-	_eXosip_delete_nonce(pub->p_last_tr->orig_request->call_id->number);
+      if (pub->p_last_tr != NULL && pub->p_last_tr->orig_request != NULL
+          && pub->p_last_tr->orig_request->call_id != NULL
+          && pub->p_last_tr->orig_request->call_id->number != NULL)
+        _eXosip_delete_nonce (pub->p_last_tr->orig_request->call_id->number);
 
-      osip_list_add (eXosip.j_transactions, pub->p_last_tr, 0);
+      osip_list_add (&eXosip.j_transactions, pub->p_last_tr, 0);
     }
   osip_free (pub);
 }
